/**
 * @file
 * Dashboard editing UI functionality.
 */

(function ($, window, Drupal, drupalSettings) {

  'use strict';
  /**
   * Drupal behavior to trigger ajax when CKEDITOR is changed.
   *
   * @type {{attach: Function}}
   */
  Drupal.behaviors.contentReadability = {
    attach: function(context, settings) {

      $('body', context).once('content_readability').each(function () {
        if (typeof CKEDITOR !== "undefined") {
          CKEDITOR.on('instanceReady', function (ev) {
            var editor = ev.editor;

            // fire when the editor instance changes.
            editor.on('change', function () {
              updateScore();
            });
            $('select#edit-content-readability-profiles').on('change',function(){
              updateScore();
            });

          });
        }
      });

      function updateScore(){


        // get the value of body field.
        let body = CKEDITOR.instances['edit-body-0-value'].getData()
        let grade = $('select#edit-content-readability-profiles').val();

        $.post('/content-readability/update-score', {data: body, grade: grade}, function(data){
          $('.content-readability-score').html(data.contentReadabilityScore);
          $('#automatedReadabilityIndex').html(data.automatedReadabilityIndex);
          $('#averageSyllablesPerWord').html(data.averageSyllablesPerWord);
          $('#averageWordsPerSentence').html(data.averageWordsPerSentence);
          $('#colemanLiauIndex').html(data.colemanLiauIndex);
          $('#contentReadabilityScore').html(data.contentReadabilityScore);
          $('#daleChallDifficultWordCount').html(data.daleChallDifficultWordCount);
          $('#daleChallReadabilityScore').html(data.daleChallReadabilityScore);
          $('#fleschKincaidGradeLevel').html(data.fleschKincaidGradeLevel);
          $('#fleschKincaidReadingEase').html(data.fleschKincaidReadingEase);
          $('#gunningFogScore').html(data.gunningFogScore);
          $('#letterCount').html(data.letterCount);
          $('#percentageWordsWithThreeSyllables').html(data.percentageWordsWithThreeSyllables);
          $('#sentenceCount').html(data.sentenceCount);
          $('#smogIndex').html(data.smogIndex);
          $('#spacheDifficultWordCount').html(data.spacheDifficultWordCount);
          $('#spacheReadabilityScore').html(data.spacheReadabilityScore);
          $('#totalSyllables').html(data.totalSyllables);
          $('#wordCount').html(data.wordCount);
          $('#wordsWithThreeSyllables').html(data.wordsWithThreeSyllables);

        });
      }
    }
  };
})(jQuery, this, Drupal, drupalSettings);
